@@ -1,8 +1,11 @@
 from socket import htons
+
 from pr2modules import protocols
 from pr2modules.netlink import nla
-from pr2modules.netlink.rtnl.tcmsg.common_act import get_tca_action
-from pr2modules.netlink.rtnl.tcmsg.common_act import tca_act_prio
+from pr2modules.netlink.rtnl.tcmsg.common_act import (
+    get_tca_action,
+    tca_act_prio,
+)
 
 
 def fix_msg(msg, kwarg):
